Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(232)

Unified Diff: runtime/vm/parser.h

Issue 1079233002: Simplify restoring of saved try contexts in async code by passing around the (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 5 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/ast_transformer.cc ('k') | runtime/vm/parser.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/parser.h
===================================================================
--- runtime/vm/parser.h (revision 45079)
+++ runtime/vm/parser.h (working copy)
@@ -628,11 +628,12 @@
void PushTry(Block* try_block);
// Pop the inner most try block from the stack.
TryStack* PopTry();
- // Collect try block scopes and indices if await or yield is in try block.
- void CheckAsyncOpInTryBlock(LocalScope** try_scope,
- int16_t* try_index,
- LocalScope** outer_try_scope,
- int16_t* outer_try_index) const;
+ // Collect saved try context variables if await or yield is in try block.
+ void CheckAsyncOpInTryBlock(
+ LocalVariable** saved_try_ctx,
+ LocalVariable** async_saved_try_ctx,
+ LocalVariable** outer_saved_try_ctx,
+ LocalVariable** outer_async_saved_try_ctx) const;
// Add specified node to try block list so that it can be patched with
// inlined finally code if needed.
void AddNodeForFinallyInlining(AstNode* node);
« no previous file with comments | « runtime/vm/ast_transformer.cc ('k') | runtime/vm/parser.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698